<?php

namespace Drupal\warmer\Plugin;

interface WarmerInterface {

  /**
   * Returns the batch size for the warming operation.
   *
   * @return int
   *   The size.
   */
  public function getBatchSize();

  /**
   * Loads multiple items based on their IDs.
   *
   * @param array
   *   The item IDs.
   *
   * @return array
   *   The loaded items.
   */
  public function loadMultiple(array $ids = []);

  /**
   * Warms multiple items.
   *
   * @param array $items
   *   The items to warm.
   *
   * @return int
   *   The number of items that were successfully warmed.
   */
  public function warmMultiple(array $items = []);

  /**
   * Builds the next batch of IDs based on a position cursor.
   *
   * @param mixed $cursor
   *   The position of the last generate batch.
   *
   * @return array
   *   The array of item IDs.
   */
  public function buildIdsBatch($cursor);

  /**
   * Checks if the plugin should warm in this particular moment.
   *
   * @return bool
   *   TRUE if the warmer is active. FALSE otherwise.
   */
  public function isActive();

  /**
   * Marks a warmer as enqueued.
   *
   * @return bool
   *   TRUE if the warmer is active. FALSE otherwise.
   */
  public function markAsEnqueued();

}
